# modsman

A Minecraft mod manager for the command line.

## Installation

This utility requires Python 3.7.

```bash
pip install modsman
```

## Usage

```bash
modsman --help
```

## Demo

[![asciicast](https://asciinema.org/a/6fdMdFGLocNdCLIsBgmMDoOB8.svg)](https://asciinema.org/a/6fdMdFGLocNdCLIsBgmMDoOB8)